@@ -46,6 +46,10 @@ class ScreenElement(object):
                  fail_message=None,
                  scroll_to_element=False,
                  container=None):
+        if self.__class__.__name__ != 'ScreenElement' and locator == None:
+            raise AttributeError(
+                f'"locator" can\'t be None for <{self.__class__.__name__}> instance.'
+                f' Must be set through the constructor...except for <ScreenElement>.')
         self.driver: WebElement | list[WebElement] = container
         self._locator: tuple[str, str] = locator
         self._wait: int = wait
@@ -75,21 +79,25 @@ class ScreenElement(object):
        :param obj: instance of class that owns the property
        :raises: :exc:`selenium.common.exceptions.TimeoutException` if timeout occurs
        """
-        if isinstance(self.driver, EventFiringWebElement):
-            self.driver = self.driver.wrapped_element
-        self._resolve_fail_message()
-        wdw = WebDriverWait(obj.driver, self._wait, self._poll_frequency, self._ignored_exceptions)
-        if self._until_not:
-            self.driver = wdw.until_not(self._verify_method(self._locator), self._fail_message)
+        if self._locator_is_none(obj):
+            return self
         else:
-            self.driver = wdw.until(self._verify_method(self._locator), self._fail_message)
-        if self._scroll_to_element:
-            self._coordinates = self.driver.location_once_scrolled_into_view
+            if isinstance(self.driver, EventFiringWebElement):
+                self.driver = self.driver.wrapped_element
+            self._resolve_fail_message()
+            wdw = WebDriverWait(obj.driver, self._wait, self._poll_frequency, self._ignored_exceptions)
+            if self._until_not:
+                self.driver = wdw.until_not(self._verify_method(self._locator), self._fail_message)
+            else:
+                self.driver = wdw.until(self._verify_method(self._locator), self._fail_message)
+            if self._scroll_to_element:
+                self._coordinates = self.driver.location_once_scrolled_into_view
+            logger.info(f'Getting <{self.driver.__class__.__name__}> instance :: {self._locator}')
+            return self.driver
 
     @aspect.log
-    def locator_is_none(self, obj):
+    def _locator_is_none(self, obj):
         """
-        When inheriting the screen element and overriding the __get__ method, it is preferable to call this method first.
         The method is intended to solve cases when the locator is not set during the construction of the element itself
         """
         if self._locator is None:
@@ -121,14 +129,8 @@ class ScreenElement(object):
     def __get__(self, obj, owner):
         """
         Gets the ScreenElement or WebElement based on condition if locator property is set.
-        When overriding the ScreenElement "if" block is desirable to handle cases when locator is not set in constructor
         """
-        if self.locator_is_none(obj):
-            return self
-        else:
-            self._refresh(obj)
-            logger.info(f'Getting <{self.driver.__class__.__name__}> instance :: {self._locator}')
-            return self.driver
+        return self._refresh(obj)
 
     @aspect.log
     def __getattr__(self, attr):
@@ -137,7 +139,7 @@ class ScreenElement(object):
         web_element_methods_and_props = get_methods_and_properties(WebElement, dont=True, starts_with='_')
         if attr in web_element_methods_and_props:
             errmsg = f'<{class_instance}> object has no attribute "{attr}". To be referenced as a <WebElement> {class_instance}.locator property must me set!'
-            infomsg = f'<{class_instance}> available methods and properties for setting locator: {screen_element_methods_and_props}'
+            infomsg = f'<{class_instance}> available methods and properties for setting locator: {screen_element_methods_and_props}. Or through the constructor.'
             logger.error(errmsg)
             logger.info(infomsg)
             raise AttributeError(errmsg)
@@ -151,11 +153,17 @@ class SectionElement(ScreenElement):
     def __get__(self, obj, owner):
         """Gets the section with WebElements"""
         super(SectionElement, self).__get__(obj, owner)
-        if self.locator_is_none(obj):
-            return self
-        else:
-            self._refresh(obj)
-            return self
+        return self
+
+
+@aspect.log
+class LabelElement(ScreenElement):
+    """LabelElement class that is initialized on label screen object class."""
+
+    def __get__(self, obj, owner):
+        """Gets the text of the specified object"""
+        super(LabelElement, self).__get__(obj, owner)
+        return self.driver.text
 
 
 @aspect.log
@@ -171,23 +179,9 @@ class InputElement(ScreenElement):
     def __get__(self, obj, owner):
         """Gets the text of the specified object"""
         super(InputElement, self).__get__(obj, owner)
-        self.locator_is_none(obj)
-        self._refresh(obj)
         return self.driver.get_attribute("value")
 
 
-@aspect.log
-class LabelElement(ScreenElement):
-    """LabelElement class that is initialized on label screen object class."""
-
-    def __get__(self, obj, owner):
-        """Gets the text of the specified object"""
-        super(LabelElement, self).__get__(obj, owner)
-        self.locator_is_none(obj)
-        self._refresh(obj)
-        return self.driver.text
-
-
 @aspect.log
 class SelectElement(ScreenElement):
     """SelectElement class that is initialized on select screen object class."""
@@ -206,8 +200,6 @@ class SelectElement(ScreenElement):
     def __get__(self, obj, owner):
         """Gets the text of the selected object in dropdown"""
         super(SelectElement, self).__get__(obj, owner)
-        self.locator_is_none(obj)
-        self._refresh(obj)
         selected_option = Select(self.driver).first_selected_option
         self.text = selected_option.text.strip()
         if self.enabled_check:
